@@ -3,22 +3,14 @@
  * plugins/autosubscribe/setup.php -- Main setup script
  *
  * SquirrelMail AutoSubscribe Plugin
- * Copyright (C) 2004-2005 Tomas Kuliavas <tokul@users.sourceforge.net>
+ * Copyright (C) 2004-2006 Tomas Kuliavas <tokul@users.sourceforge.net>
  * This program is licensed under GPL. See COPYING for details
  *
- * @version $Id: setup.php,v 1.4 2005/03/27 08:18:09 tokul Exp $
+ * @version $Id: setup.php,v 1.7 2006/09/02 09:41:35 tokul Exp $
  * @package sm-plugins
  * @subpackage autosubscribe
  */
 
-/** 
- * make sure SM_PATH is defined
- * @ignore
- */
-if (!defined('SM_PATH'))  {
-    define('SM_PATH','../../');
-}
-
 /**
  * init function
  */
@@ -50,6 +42,5 @@ function autosubscribe_special($mb) {
  * @return string
  */
 function autosubscribe_version() {
-  return '1.0';
+  return '1.1';
 }
-?>
\ No newline at end of file
